Page 6 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 6

Home

    have worked in secret and have usually been organized.
    Because of this, the secret side of history has often been
    the instigator of major world events.

    Since as recorded in Luke 12:2, "For there is nothing
    covered, that shall not be revealed;..." those secrets
    eventually come to light. Unfortunately, this often occurs
    after the damage has been done. Although ignored by
    most historians, the secret side of history is usually the
    most important part of history. By the secret side of
    history we mean the behind-the-scenes forces,

    history ‘we mean the behind-the-scenes forces,
    individuals, and decisions withheld from the general

    the

    we

    mean

    public.

    the organized forces behind contemporary events, and to
    use truth as a weapon against the perpetrators of evil

    deeds.

    While doing so, it will be necessary not only to
    examine some of the men and organizations involved in
    today's secret side of history, it will be necessary also to
    examine some of the important individuals and
    organizations that are working to delay and eventually
    block the movement to lead the entire human race into a

    It may surprise our most perceptive readers to learn
    that the Apostle John, writing more than 1900 years ago,
    described the existence of a political and spiritual giant
    that parallels today's emerging New World Order. Not

    The Secret Side of History

    .." those secrets

    This book seeks to stimulate readers to search out

    Satanic New World Order.